#' Opens the FFTrees package guide
#' @importFrom utils vignette
#' @export
#'

FFTrees.guide <- function() {

  vignette("guide", package = "FFTrees")

}
